@@ -606,6 +606,7 @@ QProcessEnvironment MinecraftInstance::createLaunchEnvironment()
             // dlsym variant is only needed for OpenGL and not included in the vulkan layer
             appendLib("libMangoHud_dlsym.so");
             appendLib("libMangoHud_opengl.so");
+            appendLib("libMangoHud_shim.so");
             preloadList << mangoHudLibString;
         }
 
@@ -1083,17 +1084,10 @@ shared_qobject_ptr<LaunchTask> MinecraftInstance::createLaunchTask(AuthSessionPt
         process->appendStep(step);
     }
 
-    // run pre-launch command if that's needed
-    if (getPreLaunchCommand().size()) {
-        auto step = makeShared<PreLaunchCommand>(pptr);
-        step->setWorkingDirectory(gameRoot());
-        process->appendStep(step);
-    }
-
     // load meta
     {
         auto mode = session->status != AuthSession::PlayableOffline ? Net::Mode::Online : Net::Mode::Offline;
-        process->appendStep(makeShared<TaskStepWrapper>(pptr, makeShared<MinecraftLoadAndCheck>(this, mode, pptr)));
+        process->appendStep(makeShared<TaskStepWrapper>(pptr, makeShared<MinecraftLoadAndCheck>(this, mode)));
     }
 
     // check java
@@ -1102,6 +1096,13 @@ shared_qobject_ptr<LaunchTask> MinecraftInstance::createLaunchTask(AuthSessionPt
         process->appendStep(makeShared<CheckJava>(pptr));
     }
 
+    // run pre-launch command if that's needed
+    if (getPreLaunchCommand().size()) {
+        auto step = makeShared<PreLaunchCommand>(pptr);
+        step->setWorkingDirectory(gameRoot());
+        process->appendStep(step);
+    }
+
     // if we aren't in offline mode,.
     if (session->status != AuthSession::PlayableOffline) {
         if (!session->demo) {
