@@ -1,4 +1,5 @@
 #include "ScrollMessageBox.h"
+#include <QPushButton>
 #include "ui_ScrollMessageBox.h"
 
 ScrollMessageBox::ScrollMessageBox(QWidget* parent, const QString& title, const QString& text, const QString& body)
@@ -8,6 +9,9 @@ ScrollMessageBox::ScrollMessageBox(QWidget* parent, const QString& title, const
     this->setWindowTitle(title);
     ui->label->setText(text);
     ui->textBrowser->setText(body);
+
+    ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
+    ui->buttonBox->button(QDialogButtonBox::Ok)->setText(tr("OK"));
 }
 
 ScrollMessageBox::~ScrollMessageBox()
